==> maemo-geolocation_1.0.7-1.tar.gz: maemo-geolocation-1.0.7/src/MaemoLocationProvider.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Geolocation.
 *
 * The Initial Developer of the Original Code is Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Doug Turner <dougt@meer.net>  (Original Author)
 *  Nino D'Aversa <ninodaversa@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsCOMPtr.h"
#include "nsAutoPtr.h"
#include "nsCOMArray.h"
#include "nsTArray.h"
#include "nsITimer.h"
#include "nsIObserver.h"
#include "nsIURI.h"

#include "nsWeakPtr.h"
#include "nsCycleCollectionParticipant.h"

#include "nsIDOMGeoGeolocation.h"
#include "nsIDOMGeoPosition.h"
#include "nsIDOMGeoPositionError.h"
#include "nsIDOMGeoPositionCallback.h"
#include "nsIDOMGeoPositionErrorCallback.h"
#include "nsIDOMGeoPositionOptions.h"
#include "nsIDOMNavigatorGeolocation.h"
#include "nsIDOMGeoPositionCoords.h"

#include "nsPIDOMWindow.h"

#include "nsIGeolocationProvider.h"


extern "C"
{
#include <location/location-gps-device.h>
#include <location/location-gpsd-control.h>
}

class MaemoLocationProvider : public nsIGeolocationProvider,
                              public nsITimerCallback

{
 public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIGEOLOCATIONPROVIDER
  NS_DECL_NSITIMERCALLBACK

  MaemoLocationProvider();

  void Update(nsIDOMGeoPosition* aPosition);

 private:
  ~MaemoLocationProvider();

  nsresult StartControl();
  nsresult StartDevice();

  static void DeviceDisconnected(LocationGPSDevice* device, void* self);
  static void ControlStopped(LocationGPSDControl* device, void* self);
  static void ControlError(LocationGPSDControl* control, void* self);
  static void LocationChanged(LocationGPSDevice* device, void* self);

  gulong mLocationChanged;
  gulong mControlError;
  gulong mDeviceDisconnected;
  gulong mControlStopped;

  nsCOMPtr<nsIGeolocationUpdate> mCallback;
  PRPackedBool mHasSeenLocation;
  PRPackedBool mHasGPS;

  nsCOMPtr<nsITimer> mUpdateTimer;
  LocationGPSDControl* mGPSControl;
  LocationGPSDevice* mGPSDevice;
};

==> maemo-geolocation_1.1.2-1.tar.gz: maemo-geolocation-1.1.2/src/MaemoLocationProvider.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Geolocation.
 *
 * The Initial Developer of the Original Code is Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Doug Turner <dougt@meer.net>  (Original Author)
 *  Nino D'Aversa <ninodaversa@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsCOMPtr.h"
#include "nsAutoPtr.h"
#include "nsCOMArray.h"
#include "nsTArray.h"
#include "nsITimer.h"
#include "nsIObserver.h"
#include "nsIURI.h"

#include "nsWeakPtr.h"
#include "nsCycleCollectionParticipant.h"

#include "nsIDOMGeoGeolocation.h"
#include "nsIDOMGeoPosition.h"
#include "nsIDOMGeoPositionError.h"
#include "nsIDOMGeoPositionCallback.h"
#include "nsIDOMGeoPositionErrorCallback.h"
#include "nsIDOMGeoPositionOptions.h"
#include "nsIDOMNavigatorGeolocation.h"
#include "nsIDOMGeoPositionCoords.h"

#include "nsPIDOMWindow.h"

#include "nsIGeolocationProvider.h"


extern "C"
{
#include <location/location-gps-device.h>
#include <location/location-gpsd-control.h>
#include <location/location-distance-utils.h>
#include <location/location-misc.h>
}

class MaemoLocationProvider : public nsIGeolocationProvider,
                              public nsITimerCallback

{
 public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIGEOLOCATIONPROVIDER
  NS_DECL_NSITIMERCALLBACK

  MaemoLocationProvider();

  void Update(nsIDOMGeoPosition* aPosition);

 private:
  ~MaemoLocationProvider();

  nsresult StartControl();
  nsresult StartDevice();
  nsresult LocationUpdate(LocationGPSDevice* aDev);

  static void DeviceDisconnected(LocationGPSDevice* device, void* self);
  static void ControlStopped(LocationGPSDControl* device, void* self);
  static void ControlError(LocationGPSDControl* control, void* self);
  static void LocationChanged(LocationGPSDevice* device, void* self);

  gulong mLocationChanged;
  gulong mControlError;
  gulong mDeviceDisconnected;
  gulong mControlStopped;

  nsCOMPtr<nsIGeolocationUpdate> mCallback;
  PRPackedBool mHasSeenLocation;
  PRPackedBool mHasGPS;

  nsCOMPtr<nsITimer> mUpdateTimer;
  LocationGPSDControl* mGPSControl;
  LocationGPSDevice* mGPSDevice;

  PRBool mIgnoreMinorChanges;
  double mPrevLat;
  double mPrevLong;
  LocationGPSDControlInterval mInterval;
};
